@@ -145,16 +145,6 @@ def format_collection(body):  # pragma: no cover
     if 'writeConcern' in body:
         result['write_concern'] = body['writeConcern']
 
-    # MMFiles only
-    if 'doCompact' in body:
-        result['compact'] = body['doCompact']
-    if 'journalSize' in body:
-        result['journal_size'] = body['journalSize']
-    if 'isVolatile' in body:
-        result['volatile'] = body['isVolatile']
-    if 'indexBuckets' in body:
-        result['index_bucket_count'] = body['indexBuckets']
-
     # Cluster only
     if 'shards' in body:
         result['shards'] = body['shards']
@@ -187,6 +177,22 @@ def format_collection(body):  # pragma: no cover
     if 'deleted' in body:
         result['deleted'] = body['deleted']
 
+    # New in 3.7
+    if 'syncByRevision' in body:
+        result['sync_by_revision'] = body['syncByRevision']
+    if 'tempObjectId' in body:
+        result['temp_object_id'] = body['tempObjectId']
+    if 'usesRevisionsAsDocumentIds' in body:
+        result['rev_as_id'] = body['usesRevisionsAsDocumentIds']
+    if 'isDisjoint' in body:
+        result['disjoint'] = body['isDisjoint']
+    if 'isSmartChild' in body:
+        result['smart_child'] = body['isSmartChild']
+    if 'minRevision' in body:
+        result['min_revision'] = body['minRevision']
+    if 'schema' in body:
+        result['schema'] = body['schema']
+
     return verify_format(body, result)
 
 
@@ -784,6 +790,10 @@ def format_view(body):  # pragma: no cover
             format_view_consolidation_policy(body['consolidationPolicy'])
     if 'primarySort' in body:
         result['primary_sort'] = body['primarySort']
+    if 'primarySortCompression' in body:
+        result['primary_sort_compression'] = body['primarySortCompression']
+    if 'storedValues' in body:
+        result['stored_values'] = body['storedValues']
     if 'writebufferIdle' in body:
         result['writebuffer_idle'] = body['writebufferIdle']
     if 'writebufferActive' in body:
@@ -791,7 +801,10 @@ def format_view(body):  # pragma: no cover
     if 'writebufferSizeMax' in body:
         result['writebuffer_max_size'] = body['writebufferSizeMax']
     if 'links' in body:
-        result['links'] = [format_view_link(link) for link in body['links']]
+        result['links'] = {
+            name: format_view_link(link)
+            for name, link in body['links'].items()
+        }
 
     return verify_format(body, result)
 
@@ -840,3 +853,116 @@ def format_edge(body):  # pragma: no cover
         return result
     else:
         return edge
+
+
+def format_tls(body):  # pragma: no cover
+    """Format TLS data.
+
+    :param body: Input body.
+    :type body: dict
+    :return: Formatted body.
+    :rtype: dict
+    """
+    result = body
+    return verify_format(body, result)
+
+
+def format_backup(body):  # pragma: no cover
+    """Format backup data.
+
+    :param body: Input body.
+    :type body: dict
+    :return: Formatted body.
+    :rtype: dict
+    """
+    result = {}
+
+    if 'previous' in body:
+        result['previous'] = body['previous']
+    if 'id' in body:
+        result['backup_id'] = body['id']
+    if 'datetime' in body:
+        result['datetime'] = body['datetime']
+    if 'potentiallyInconsistent' in body:
+        result['potentially_inconsistent'] = body['potentiallyInconsistent']
+    if 'sizeInBytes' in body:
+        result['size_in_bytes'] = body['sizeInBytes']
+    if 'nrDBServers' in body:
+        result['dbserver_count'] = body['nrDBServers']
+    if 'nrFiles' in body:
+        result['file_count'] = body['nrFiles']
+
+    if 'available' in body:
+        result['available'] = body['available']
+    if 'version' in body:
+        result['version'] = body['version']
+    if 'keys' in body:
+        result['keys'] = body['keys']
+    if 'nrPiecesPresent' in body:
+        result['pieces_present'] = body['nrPiecesPresent']
+
+    return verify_format(body, result)
+
+
+def format_backup_restore(body):  # pragma: no cover
+    """Format backup restore data.
+
+    :param body: Input body.
+    :type body: dict
+    :return: Formatted body.
+    :rtype: dict
+    """
+    result = {}
+    if 'id' in body:
+        result['backup_id'] = body['id']
+    if 'isCluster' in body:
+        result['is_cluster'] = body['isCluster']
+    if 'previous' in body:
+        result['previous'] = body['previous']
+
+    return verify_format(body, result)
+
+
+def format_backup_dbserver(body):  # pragma: no cover
+    """Format backup DBserver data.
+
+    :param body: Input body.
+    :type body: dict
+    :return: Formatted body.
+    :rtype: dict
+    """
+    return {'status': body['Status']}
+
+
+def format_backup_transfer(body):  # pragma: no cover
+    """Format backup download/upload data.
+
+    :param body: Input body.
+    :type body: dict
+    :return: Formatted body.
+    :rtype: dict
+    """
+    if isinstance(body, str):
+        return body
+
+    result = {}
+    if 'Timestamp' in body:
+        result['timestamp'] = body['Timestamp']
+    if 'DownloadId' in body:
+        result['download_id'] = body['DownloadId']
+    if 'downloadId' in body:
+        result['download_id'] = body['downloadId']
+    if 'UploadId' in body:
+        result['upload_id'] = body['UploadId']
+    if 'uploadId' in body:
+        result['upload_id'] = body['uploadId']
+    if 'Cancelled' in body:
+        result['cancelled'] = body['Cancelled']
+    if 'BackupId' in body:
+        result['backup_id'] = body['BackupId']
+    if 'DBServers' in body:
+        result['dbservers'] = {
+            k: format_backup_dbserver(v)
+            for k, v in body['DBServers'].items()
+        }
+    return verify_format(body, result)
