@@ -7,44 +7,44 @@ class Request(object):
     """HTTP request.
 
     :param method: HTTP method in lowercase (e.g. "post").
-    :type method: str | unicode
+    :type method: str
     :param endpoint: API endpoint.
-    :type endpoint: str | unicode
+    :type endpoint: str
     :param headers: Request headers.
     :type headers: dict
     :param params: URL parameters.
     :type params: dict
     :param data: Request payload.
-    :type data: str | unicode | bool | int | list | dict |
+    :type data: str | bool | int | list | dict |
         requests_toolbelt.MultipartEncoder
     :param read: Names of collections read during transaction.
-    :type read: str | unicode | [str | unicode]
+    :type read: str | [str]
     :param write: Name(s) of collections written to during transaction with
         shared access.
-    :type write: str | unicode | [str | unicode]
+    :type write: str | [str]
     :param exclusive: Name(s) of collections written to during transaction
         with exclusive access.
-    :type exclusive: str | unicode | [str | unicode]
+    :type exclusive: str | [str]
     :param deserialize: Whether the response body can be deserialized.
     :type deserialize: bool
     :ivar method: HTTP method in lowercase (e.g. "post").
-    :vartype method: str | unicode
+    :vartype method: str
     :ivar endpoint: API endpoint.
-    :vartype endpoint: str | unicode
+    :vartype endpoint: str
     :ivar headers: Request headers.
     :vartype headers: dict
     :ivar params: URL (query) parameters.
     :vartype params: dict
     :ivar data: Request payload.
-    :vartype data: str | unicode | bool | int | list | dict
+    :vartype data: str | bool | int | list | dict
     :ivar read: Names of collections read during transaction.
-    :vartype read: str | unicode | [str | unicode] | None
+    :vartype read: str | [str] | None
     :ivar write: Name(s) of collections written to during transaction with
         shared access.
-    :vartype write: str | unicode | [str | unicode] | None
+    :vartype write: str | [str] | None
     :ivar exclusive: Name(s) of collections written to during transaction
         with exclusive access.
-    :vartype exclusive: str | unicode | [str | unicode] | None
+    :vartype exclusive: str | [str] | None
     :ivar deserialize: Whether the response body can be deserialized.
     :vartype deserialize: bool
     """
